Columnar And Analytics Formats
==============================

Handlers for analytics-oriented binary table formats.

.. autosummary::
   :toctree: generated

   etlplus.file.arrow
   etlplus.file.feather
   etlplus.file.orc
   etlplus.file.parquet
